darkhistory.electrons.ics.engloss\_diff\_terms.engloss\_diff\_expansion
=======================================================================

.. currentmodule:: darkhistory.electrons.ics.engloss_diff_terms

.. autofunction:: engloss_diff_expansion